# DictionaryInfoResponse


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**last_updated** | **str** | Timestamp (UTC) when the dictionary was last updated or an item was added or removed. | [optional] 
**item_count** | **int** | The number of items currently in the dictionary. | [optional] 
**digest** | **str** | A hash of all the dictionary content. | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


